@@ -1,4 +1,4 @@
-from .scraper import Scraper, TAG_LINK
+from .scraper import Scraper, TAG_LINK, HTMLSession
 from .url import URL
 from .logging import LogConfig, LOG_LEVEL
 from .versions import __VERSION__
@@ -6,6 +6,7 @@ from .versions import __VERSION__
 __all__ = [
     "Scraper",
     "TAG_LINK",
+    "HTMLSession",
     "URL",
     "LogConfig",
     "LOG_LEVEL",
